@@ -2,13 +2,15 @@
 from .broker import Broker
 from .consumer import Consumer
 from .matchers import EachLike, Like, SomethingLike, Term, Format
-from .message_pact import MessagePact
 from .message_consumer import MessageConsumer
+from .message_pact import MessagePact
+from .message_provider import MessageProvider
 from .pact import Pact
 from .provider import Provider
 from .verifier import Verifier
 
 from .__version__ import __version__  # noqa: F401
 
-__all__ = ('Broker', 'Consumer', 'EachLike', 'Like', 'MessageConsumer', 'MessagePact',
+__all__ = ('Broker', 'Consumer', 'EachLike', 'Like',
+           'MessageConsumer', 'MessagePact', 'MessageProvider',
            'Pact', 'Provider', 'SomethingLike', 'Term', 'Format', 'Verifier')
